@@ -111,7 +111,11 @@ def syncify_func(func: Callable[P, Coro[T]]) -> Callable[P, T]:
 
     @functools.wraps(func)
     def sync_func(*args: P.args, **kwargs: P.kwargs) -> T:
-        loop = asyncio.get_running_loop()
+        try:
+            loop = asyncio.get_running_loop()
+        except RuntimeError as exc:
+            raise RuntimeError('There is not running event loop. Consider using asyncio.run().') from exc
+
         return loop.run_until_complete(func(*args, **kwargs))
 
     return sync_func
@@ -192,7 +196,7 @@ class taskify_func(Generic[T]):
 
         Add a callback to be added to the tasks done callbacks with `add_done_callback <https://docs.python.org/3/library/asyncio-task.html?highlight=asyncio%20task#asyncio.Task.add_done_callback>`_.
         """
-        if not inspect.isfunction(callback):
+        if not TYPE_CHECKING and not inspect.isfunction(callback):
             raise TypeError(f'Expected a callable function, got {callback.__class__.__name__!r}')
 
         self._done_callbacks[callback.__name__] = callback
