@@ -1,7 +1,6 @@
 import asyncio
 import datetime
-
-from ._sentinel import MISSING
+from typing import Optional
 
 
 async def sleep_until(until: datetime.datetime) -> None:
@@ -27,19 +26,22 @@ async def sleep_until(until: datetime.datetime) -> None:
     await asyncio.sleep(seconds)
 
 
-async def today_sleep_until(hours: int = MISSING, minutes: int = MISSING, seconds: int = MISSING):
+async def today_sleep_until(
+    hours: Optional[int] = None, minutes: Optional[int] = None, seconds: Optional[int] = None
+) -> None:
     """
     Sleep until a certain time. The difference between this and :func:`sleep_until` is that this only sleeps within the current day.
 
     .. versionadded:: 1.3
 
+
     Parameters
     -----------
-    hours: :class:`int`
+    hours: Optional[:class:`int`]
         The hours in the time.
-    minutes: :class:`int`
+    minutes: Optional[:class:`int`]
         The minutes in the time.
-    seconds: :class:`int`
+    seconds: Optional[:class:`int`]
         The seconds in the time.
 
 
@@ -57,13 +59,27 @@ async def today_sleep_until(hours: int = MISSING, minutes: int = MISSING, second
 
         async def main():
             await asyncify.today_sleep_until(hours=9, minutes=30)  # sleeps until 9:30 AM
+
+
+    .. note::
+        24 hour time is also supported.
     """
-    if not hours or not minutes or not seconds:
+    if hours is None and minutes is None and seconds is None:
         raise TypeError('You must provide hours, minutes, or seconds.')
 
+    if not hours:
+        hours = 0
+    if not minutes:
+        minutes = 0
+    if not seconds:
+        seconds = 0
+
+    if hours > 12:
+        hours -= 12
+
     now = datetime.datetime.now()
     total_seconds_now = (now.hour * 3600) + (now.minute * 60) + now.second
-    total_seconds = (hours * 3600) + (minutes * 60) + (seconds * 1)
+    total_seconds = (hours * 3600) + (minutes * 60) + seconds
 
     sleep_time = total_seconds - total_seconds_now
     await asyncio.sleep(sleep_time)
